# Utilities for differentiable computational photonics

General functionality for building structures and using input/output modes on finite-difference Yee cell grids.
Intended for use with simulation engines such as, but not limited to, [fdtd-z](https://github.com/spinsphotonics/fdtdz).
Built on top of [JAX](https://github.com/google/jax) to enable optimization and design use cases.
